@@ -76,7 +76,7 @@ class Orden(BaseModel):
     # additional general info
     op_iva: Optional[float] = None
     op_ref_numerica: Optional[int] = None
-    op_ref_cobranza: Optional[int] = None
+    op_ref_cobranza: Optional[str] = None
     op_clave_pago: Optional[str] = None
     # refunds info
     op_to_clave: Optional[int] = None
