@@ -1,7 +1,5 @@
 from enum import Enum
 
-from spei.errors import generate_error_codes
-
 
 class TipoPagoOrdenPago(str, Enum):
     devolucion_no_acreditada = '0'
@@ -103,8 +101,8 @@ class ClaveOrdenanteOrdenPago(int, Enum):
     GEMELA = 699
 
 
-class FolioOrdenPago(str, Enum):
-    cargar_odp = '-1'
+class FolioOrdenPago(int, Enum):
+    cargar_odp = -1
 
 
 class MedioEntregaOrdenPago(str, Enum):
@@ -167,6 +165,3 @@ class TipoDevolucionOrdenPago(str, Enum):
     codi_payment_notification_timeout = 28
     duplicated_tracking_code = 30
     origin_institution_certificate_expired = 31
-
-
-CodigoError = generate_error_codes()
